@@ -110,7 +110,8 @@ RESULT_TEXT        =3
 RESULT_RECORD_ID   =4
 
 
-baseUrl = "https://www.look-spot.ca/lsservices/ws"
+baseUrl = "https://www.look-spot.ca/lookspotapi/ws"
+#/testimagelookspot/upload
 CODE = 'code'
 DESC = 'description'
 RSLT = 'result'
@@ -121,6 +122,6 @@ MSSG = 'message'
 ADDRESS =["finch","Toronto","Canada"]
 
 
-SIGNATURE = "client=laipac&signature=laipacws"
-USER      = "userid=feng.gao@laipac.com&password=123456"
+#@SIGNATURE = "client=laipac&signature=laipacws"
+#USER      = "userid=feng.gao@laipac.com&password=123456"
 SERIAL_NO = "654321"
\ No newline at end of file
